# pyETT: Python library for Eleven VR Table Tennis data

[![PyPi Status](https://img.shields.io/pypi/v/pyETT)](https://pypi.org/project/pyETT/)
[![PyPi Downloads](https://img.shields.io/pypi/dm/pyETT)](https://pypi.org/project/pyETT/)
[![Documentation Status](https://readthedocs.org/projects/pyett/badge/?version=latest)](https://pyett.readthedocs.io/en/latest/?badge=latest)
[![Build](https://img.shields.io/github/workflow/status/souzatharsis/pyETT/pyett-tests)](https://github.com/souzatharsis/pyETT/actions)
[![Issues](https://img.shields.io/github/issues-raw/souzatharsis/pyETT)](https://github.com/souzatharsis/pyETT/issues)
![Discord](https://img.shields.io/discord/340715434099605515)
[![License: CC BY-NC-SA 4.0](https://img.shields.io/badge/License-CC%20BY--NC--SA%204.0-lightgrey.svg)](https://creativecommons.org/licenses/by-nc-sa/4.0/)

![Eleven VR](https://cdn.akamai.steamstatic.com/steam/apps/488310/capsule_616x353.jpg)

## Documentation

Documentation for pyETT is located at https://pyett.readthedocs.io/.

## Installation

From PyPI

`$ pip install pyETT`

## License

Licensed under Attribution-NonCommercial-ShareAlike 4.0 International.

<img src="fig/by-nc-sa.png" width="20%">
